@@ -1,6 +1,6 @@
 package Acme'Schrodinger'Do;
-our $VERSION = '0.01';
-sub sdo (&;$) {shift->() if defined $_[1] ? $_[1] > rand(100) : 1}
+our $VERSION = '0.03';
+sub sdo (&;$$) {for(1..(defined $_[2] ? $_[2] : 1)){$_[0]->() if defined $_[1] ? $_[1] > rand(100) : 1}}
 sub import {*{caller().'::sdo'} = \&sdo}
 1;
 __END__
@@ -12,6 +12,7 @@ Acme::Schrodinger::Do - do block occasionally
 
   use Acme'Schrodinger'Do;
   sdo {kill $the,$cat} '50%';
+  sdo {kill $the,$cat} 50 => 10                       # 10 boxes and cats
 
 =head1 DESCRIPTION
 
@@ -20,12 +21,15 @@ You won't know if Perl will do it,
 
 =head2 EXPORT
 
-sdo BLOCK [Probability]
+sdo BLOCK
+sdo BLOCK Probablilty
+sdo BLOCK Probability => Iterate
 
 	sdo {print 'Never Print',"\n"} '0%';              # never print
 	sdo {print 'The `%\' can be ommited!',"\n"} 0;    # same as above
 	sdo {print 'Just do it!',"\n"} 100;               # like 'do' block
 	sdo {print 'Just do it!',"\n"};                   # like 'do' block
+	sdo {print 'do it three times!'} 100 => 3;        # do for 1..3
 
 =head1 SEE ALSO
 
